#ifndef __OPENB3D_BI__
#define __OPENB3D_BI__

#ifdef __FB_WIN32__
 #libpath "lib/win32"
#else
 #libpath "lib/linux"
#endif

#inclib "OpenB3D"

#ifndef NULL
 #define NULL cptr(any ptr,0)
#endif


enum SPRITE_VIEW_MODE
  MODE_FIXED    = 1 ' sprite always faces camera - default
  MODE_FREE     = 2 ' sprite is independent of camera
  MODE_UPRIGHT1 = 3 ' sprite always faces camera, but rolls with camera as well, unlike mode no.1
  MODE_UPRIGHT2 = 4 ' sprite always remains upright. Gives a 'billboard' effect. Good for trees, spectators etc.
end enum

enum TEXTURE_FLAG
  FLAG_COLOR     = (1 shl 0) ' default
  FLAG_ALPHA     = (1 shl 1)
  FLAG_MASKED    = (1 shl 2)
  FLAG_MIPMAPPED = (1 shl 3)
  FLAG_CLAMPU    = (1 shl 4)
  FLAG_CLAMPV    = (1 shl 5)
  FLAG_SPHERIAL  = (1 shl 6) ' Spherical reflection map
  FLAG_CUBIC     = (1 shl 7) ' Cubic environment map
  FLAG_VRAM      = (1 shl 8) ' Store texture in vram
  FLAG_HIGHCOLOR = (1 shl 9) ' Force the use of high color textures
end enum

enum TEXTURE_CUBE_FACE
  FACE_LEFT = 0 ' (negative X) face
  FACE_FORWARD  ' (positive Z) face - this is the default.
  FACE_RIGHT    ' (positive X) face
  FACE_BACKWARD ' (negative Z) face
  FACE_UP       ' (positive Y) face
  FACE_DOWN     ' (negative Y) face
end enum

enum TEXTURE_CUBE_MODE
  MODE_SPECULAR = 1 ' (default)
  MODE_DIFUSE
  MODE_REFRACTION
end enum

enum PICK_MODE
  PICK_NONE   = 0 ' (default)
  PICK_SPHERE     ' (EntityRadius is used)
  PICK_POLYGON
  PCK_BOX         ' (EntityBox is used)
end enum

type _TEXTURE
  as any ptr pClass
end type
type TEXTURE as _TEXTURE ptr

type _SPRITE
  as any ptr pClass
end type
type SPRITE as _SPRITE ptr

type _BRUSH
  as any ptr pClass
end type
type BRUSH as _BRUSH ptr

type _MESH
  as any ptr pClass
end type
type MESH as _MESH ptr

type _SURFACE
  as any ptr pClass
end type
type SURFACE as _SURFACE ptr

type _TERRAIN
  as any ptr pClass
end type
type TERRAIN as _TERRAIN ptr

type _CAMERA
  as any ptr pClass
end type
type CAMERA as _CAMERA ptr

type _LIGHT
  as any ptr pClass
end type
type LIGHT as _LIGHT ptr

type _SHADOW
  as any ptr pClass
end type
type SHADOW as _SHADOW ptr

type ENTITY as any ptr


' global
declare sub      Graphics3D   cdecl alias "Graphics3D"  (width as integer, height as integer, depth as integer=0, mode as integer=0, rate as integer=60)
declare sub      AntiAlias    cdecl alias "AntiAlias"   (samples as integer)
declare function Wireframe    cdecl alias "Wireframe"   (enable as integer) as integer
declare sub      AmbientLight cdecl alias "AmbientLight"(r as single, g as single, b as single)
declare function UpdateWorld  cdecl alias "UpdateWorld" (anim_speed as single=1) as integer
declare sub      RenderWorld  cdecl alias "RenderWorld"
declare sub      ClearWorld   cdecl alias "ClearWorld"  (entities as integer=1, brushes as integer=1, textures as integer=1)
declare sub      Collisions   cdecl alias "Collisions"  (src_no as integer, dest_no as integer, method_no as integer, response_no as integer=0)
declare sub      ClearTextureFilters cdecl alias "ClearTextureFilters"
' sprite
declare function CreateSprite   cdecl alias "CreateSprite" (parent as ENTITY=NULL) as SPRITE
declare function LoadSprite     cdecl alias "LoadSprite" (tex_file as zstring ptr, texflag as TEXTURE_FLAG=FLAG_COLOR, parent as ENTITY=NULL) as SPRITE
declare sub      SpriteViewMode cdecl alias "SpriteViewMode" (sprite as SPRITE, mode as SPRITE_VIEW_MODE)
declare sub      HandleSprite   cdecl alias "HandleSprite" (sprite as SPRITE, h_x as single, h_y as single)
declare sub      RotateSprite   cdecl alias "RotateSprite" (sprite as SPRITE, ang as single)
declare sub      ScaleSprite    cdecl alias "ScaleSprite" (sprite as SPRITE, s_x as single, s_y as single)

' texture
declare function CreateTexture   cdecl alias "CreateTexture"  (width as integer, height as integer, flags as TEXTURE_FLAG=FLAG_COLOR, frames as integer=1) as TEXTURE
declare function LoadTexture     cdecl alias "LoadTexture"    (file as zstring ptr, flags as TEXTURE_FLAG=FLAG_COLOR) as any ptr
declare function LoadAnimTexture cdecl alias "LoadAnimTexture"(file as zstring ptr, flags as TEXTURE_FLAG, frame_width as integer, frame_height as integer, first_frame as integer, frame_count as integer) as any ptr
declare sub      FreeTexture     cdecl alias "FreeTexture"    (tex as TEXTURE)
declare function TextureName     cdecl alias "TextureName"    (tex as TEXTURE) as zstring ptr
declare sub      PositionTexture cdecl alias "PositionTexture"(tex as TEXTURE, u_pos as integer, v_pos as integer)
declare sub      RotateTexture   cdecl alias "RotateTexture"  (tex as TEXTURE, ang as single)
declare sub      ScaleTexture    cdecl alias "ScaleTexture"   (tex as TEXTURE, u_scale as single, v_scale as single)
declare sub      SetCubeFace     cdecl alias "SetCubeFace"    (tex as TEXTURE, face as TEXTURE_CUBE_FACE)
declare sub      SetCubeMode     cdecl alias "SetCubeMode"    (tex as TEXTURE, mode as TEXTURE_CUBE_MODE)
declare function TextureBlend    cdecl alias "TextureBlend"   (tex as TEXTURE, blend as integer) as integer
declare function TextureCoords   cdecl alias "TextureCoords"  (tex as TEXTURE, coords as integer) as integer
declare function TextureWidth    cdecl alias "TextureWidth"   (tex as TEXTURE) as integer
declare function TextureHeight   cdecl alias "TextureHeight"  (tex as TEXTURE) as integer
declare function TextureFilter   cdecl alias "TextureFilter"  (match_text as zstring ptr, flags as TEXTURE_FLAG) as integer

declare sub BackBufferToTex cdecl alias "BackBufferToTex"(tex as TEXTURE, frame as integer=0)
declare sub BufferToTex     cdecl alias "BufferToTex"    (tex as TEXTURE, buffer as any ptr, frame as integer)
declare sub TexToBuffer     cdecl alias "TexToBuffer"    (tex as TEXTURE, buffer as any ptr, frame as integer)

' brush
declare function CreateBrush     cdecl alias "CreateBrush"    (r as single=255, g as single=255, b as single=255) as BRUSH
declare function LoadBrush       cdecl alias "LoadBrush"      (file as zstring ptr, flags as integer=1, u_scale as single=1, v_scale as single=1) as any ptr
declare sub      FreeBrush       cdecl alias "FreeBrush"      (br as BRUSH)
declare sub      BrushAlpha      cdecl alias "BrushAlpha"     (br as BRUSH, a as single)
declare sub      BrushBlend      cdecl alias "BrushBlend"     (br as BRUSH, blend as integer)
declare sub      BrushColor      cdecl alias "BrushColor"     (br as BRUSH, r as single, g as single, b as single)
declare sub      BrushFX         cdecl alias "BrushFX"        (br as BRUSH, fx as integer)
declare sub      BrushShininess  cdecl alias "BrushShininess" (br as BRUSH, s as single)
declare sub      BushTexture     cdecl alias "BrushTexture"   (br as BRUSH, tex as TEXTURE, frame as integer=0, index as integer=0)
declare function GetBrushTexture cdecl alias "GetBrushTexture"(br as BRUSH, index as integer=0) as TEXTURE

' camera
declare function CreateCamera   cdecl alias "CreateCamera"   (parent as ENTITY=NULL) as CAMERA
declare sub      CameraClsColor cdecl alias "CameraClsColor" (cam as CAMERA, r as single, g as single, b as single)
declare sub      CameraClsMode  cdecl alias "CameraClsMode"  (cam as CAMERA, cls_depth as integer, cls_zbuffer as integer)
declare sub      CameraFogColor cdecl alias "CameraFogColor" (cam as CAMERA, r as single, g as single, b as single)
declare sub      CameraFogMode  cdecl alias "CameraFogMode"  (cam as CAMERA, mode as integer)
declare sub      CameraFogRange cdecl alias "CameraFogRange" (cam as CAMERA, nnear as single, nfar as single)
declare sub      CameraProject  cdecl alias "CameraProject"  (cam as CAMERA, x as single, y as single, z as single)
declare sub      CameraProjMode cdecl alias "CameraProjMode" (cam as CAMERA, mode as integer)
declare sub      CameraRange    cdecl alias "CameraRange"    (cam as CAMERA, nnear as single, nfar as single)
declare sub      CameraViewport cdecl alias "CameraViewport" (cam as CAMERA, x as integer, y as integer, width as integer, height as integer)
declare sub      CameraZoom     cdecl alias "CameraZoom"     (cam as CAMERA, zoom as single)
declare function CameraPick     cdecl alias "CameraPick"     (cam as CAMERA, x as single, y as single) as ENTITY

' mesh
declare function CreateMesh   cdecl alias "CreateMesh" (parent as ENTITY=NULL) as MESH
declare function LoadMesh     cdecl alias "LoadMesh" (file as zstring ptr, parent as ENTITY=NULL) as any ptr
declare function LoadAnimMesh cdecl alias "LoadAnimMesh" (file as zstring ptr, parent as ENTITY=NULL) as any ptr

declare function CopyMesh cdecl alias "CopyMesh" (mesh as MESH, parent as ENTITY=NULL) as any ptr
declare sub      AddMesh  cdecl alias "AddMesh" (mesh as MESH, other as MESH)

declare function PaintMesh cdecl alias "PaintMesh" (mesh as MESH, br as BRUSH) as any ptr

declare function MeshWidth      cdecl alias "MeshWidth" (mesh as MESH) as single
declare function MeshHeight     cdecl alias "MeshHeight" (mesh as MESH) as single
declare function MeshDepth      cdecl alias "MeshDepth" (mesh as MESH) as single
declare function MeshCullRadius cdecl alias "MeshCullRadius" (ent as ENTITY, radius as single) as integer

declare sub      PositionMesh  cdecl alias "PositionMesh" (mesh as MESH, px as single, py as single, pz as single)
declare function RotateMesh    cdecl alias "RotateMesh" (mesh as MESH, pitch as single, yaw as single, roll as single) as any ptr
declare sub      ScaleMesh     cdecl alias "ScaleMesh" (mesh as MESH, sx as single, sy as single, sz as single)
declare function UpdateNormals cdecl alias "UpdateNormals" (mesh as MESH) as integer

declare function CountSurfaces cdecl alias "CountSurfaces" (mesh as MESH) as integer
declare function GetSurface    cdecl alias "GetSurface" (mesh as MESH, surf_no as integer) as SURFACE
declare function FindSurface   cdecl alias "FindSurface" (mesh as MESH, br as BRUSH) as any ptr

declare function FitMesh         cdecl alias "FitMesh" (mesh as MESH, x as single, y as single, z as single, width as single, height as single, depth as single, uniform as integer=0) as any ptr
declare function FlipMesh        cdecl alias "FlipMesh" (mesh as MESH) as any ptr
declare function MeshesIntersect cdecl alias "MeshesIntersect" (mesh as MESH, other as MESH) as any ptr

' surface
declare function CreateSurface   cdecl alias "CreateSurface" (mesh as MESH, br as BRUSH=NULL) as SURFACE
declare sub      ClearSurface    cdecl alias "ClearSurface" (surf as SURFACE, clear_verts as integer=1, clear_tris as integer=1)
declare sub      PaintSurface    cdecl alias "PaintSurface" (surf as SURFACE, br as BRUSH)
declare function GetSurfaceBrush cdecl alias "GetSurfaceBrush" (surf as SURFACE) as any ptr
declare function CountTriangles  cdecl alias "CountTriangles" (surf as SURFACE) as integer
declare function CountVertices   cdecl alias "CountVertices" (surf as SURFACE) as integer

declare function AddVertex      cdecl alias "AddVertex" (surf as SURFACE, x as single, y as single, z as single, u as single=0, v as single=0, w as single=0) as integer
declare function AddTriangle    cdecl alias "AddTriangle" (surf as SURFACE, v0 as integer, v1 as integer, v2 as integer) as integer
declare function TriangleVertex cdecl alias "TriangleVertex" (surf as SURFACE, tri_no as integer, corner as integer) as integer
declare function VertexColor    cdecl alias "VertexColor" (surf as SURFACE, vid as integer, r as single, g as single, b as single, a as single=1) as integer
declare function VertexRed      cdecl alias "VertexRed" (surf as SURFACE, vid as integer) as single
declare function VertexGreen    cdecl alias "VertexGreen" (surf as SURFACE, vid as integer) as single
declare function VertexBlue     cdecl alias "VertexBlue" (surf as SURFACE, vid as integer) as single
declare function VertexAlpha    cdecl alias "VertexAlpha" (surf as SURFACE, vid as integer) as single

declare sub      VertexCoords cdecl alias "VertexCoords" (surf as SURFACE, vid as integer, x as single, y as single, z as single)
declare function VertexX      cdecl alias "VertexX" (surf as SURFACE, vid as integer) as single
declare function VertexY      cdecl alias "VertexY" (surf as SURFACE, vid as integer) as single
declare function VertexZ      cdecl alias "VertexZ" (surf as SURFACE, vid as integer) as single

declare function VertexNormal cdecl alias "VertexNormal" (surf as SURFACE, vid as integer, nx as single, ny as single, nz as single) as integer
declare function VertexNX     cdecl alias "VertexNX" (surf as SURFACE, vid as integer) as single
declare function VertexNY     cdecl alias "VertexNY" (surf as SURFACE, vid as integer) as single
declare function VertexNZ     cdecl alias "VertexNZ" (surf as SURFACE, vid as integer) as single

declare function VertexTexCoords cdecl alias "VertexTexCoords" (surf as SURFACE, vid as integer, u as single, v as single, w as single=0, coord_set as integer=0) as integer
declare function VertexU         cdecl alias "VertexU" (surf as SURFACE, vid as integer, coord_set as integer=0) as single
declare function VertexV         cdecl alias "VertexV" (surf as SURFACE, vid as integer, coord_set as integer=0) as single
declare function VertexW         cdecl alias "VertexW" (surf as SURFACE, vid as integer, coord_set as integer=0) as single

' light
declare function CreateLight     cdecl alias "CreateLight"    (light_type as integer=1, parent as ENTITY=NULL) as LIGHT
declare sub      LightColor      cdecl alias "LightColor"     (light as LIGHT, red as single, green as single, blue as single)
declare sub      LightConeAngles cdecl alias "LightConeAngles"(light as LIGHT, inner_ang as single, outer_ang as single)
declare sub      LightRange      cdecl alias "LightRange"     (light as LIGHT, range as single)

' shadow
declare function CreateShadow cdecl alias "CreateShadow"(parent as any ptr, Static as integer=0) as SHADOW
declare function FreeShadow   cdecl alias "FreeShadow"  (parent as any ptr, Static as integer=0) as any ptr

' terrain
declare function CreateTerrain cdecl alias "CreateTerrain" (size as integer, parent as ENTITY ptr=NULL) as TERRAIN
declare function LoadTerrain   cdecl alias "LoadTerrain"   (file as zstring ptr, parent as ENTITY ptr=NULL) as TERRAIN
declare sub      ModifyTerrain cdecl alias "ModifyTerrain" (terr as TERRAIN, x as integer, z as integer, height as single)
declare function TerrainHeight cdecl alias "TerrainHeight" (terr as TERRAIN, x as integer, z as integer) as single
declare function TerrainX      cdecl alias "TerrainX"      (terr as TERRAIN, x as single, y as single, z as single) as single
declare function TerrainY      cdecl alias "TerrainY"      (terr as TERRAIN, x as single, y as single, z as single) as single
declare function TerrainZ      cdecl alias "TerrainZ"      (terr as TERRAIN, x as single, y as single, z as single) as single

' entity
declare function CreatePivot    cdecl alias "CreatePivot"    (parent as ENTITY=NULL) as any ptr
declare function CreateCube     cdecl alias "CreateCube"     (parent as ENTITY=NULL) as ENTITY
declare function CreateSphere   cdecl alias "CreateSphere"   (segments as integer=8, as ENTITY=NULL) as any ptr
declare function CreateCone     cdecl alias "CreateCone"     (segments as integer=8, solid as integer=1, parent as ENTITY=NULL) as ENTITY
declare function CreateCylinder cdecl alias "CreateCylinder" (segments as integer=8, solid as integer=1, parent as ENTITY=NULL) as ENTITY
declare function CreatePlane    cdecl alias "CreatePlane"    (Divisions as integer=1, parent as ENTITY=NULL) as ENTITY
declare function CopyEntity     cdecl alias "CopyEntity"     (ent as ENTITY, parent as ENTITY=NULL) as any ptr
declare sub      FreeEntity     cdecl alias "FreeEntity"     (ent as ENTITY)

declare function AddAnimSeq cdecl alias "AddAnimSeq"(ent as ENTITY, length as integer) as integer
declare sub      Animate    cdecl alias "Animate"   (ent as ENTITY, mode as integer=1, speed as single=1, seq as integer=0, trans as integer=0)
declare function Animating  cdecl alias "Animating" (ent as ENTITY) as integer
declare function AnimLength cdecl alias "AnimLength"(ent as ENTITY) as integer
declare function AnimSeq    cdecl alias "AnimSeq"   (ent as ENTITY) as integer
declare function AnimTime   cdecl alias "AnimTime"  (ent as ENTITY) as single

declare function CountCollisions cdecl alias "CountCollisions"(ent as ENTITY) as integer
declare function CollisionEntity cdecl alias "CollisionEntity"(ent as ENTITY, index as integer) as any ptr
declare function CollisionNX     cdecl alias "CollisionNX"    (ent as ENTITY, index as integer) as single
declare function CollisionNY     cdecl alias "CollisionNY"    (ent as ENTITY, index as integer) as single
declare function CollisionNZ     cdecl alias "CollisionNZ"    (ent as ENTITY, index as integer) as single

declare function CollisionTime     cdecl alias "CollisionTime"    (ent as ENTITY, index as integer) as single
declare function CollisionTriangle cdecl alias "CollisionTriangle"(ent as ENTITY, index as integer) as integer
declare function CollisionSurface  cdecl alias "CollisionSurface" (ent as ENTITY, index as integer) as any ptr

declare function CollisionX cdecl alias "CollisionX" (ent as ENTITY, index as integer) as single
declare function CollisionY cdecl alias "CollisionY" (ent as ENTITY, index as integer) as single
declare function CollisionZ cdecl alias "CollisionZ" (ent as ENTITY, index as integer) as single

declare function CountChildren   cdecl alias "CountChildren"  (ent as ENTITY) as integer
declare function FindChild       cdecl alias "FindChild"      (ent as ENTITY, child_name as zstring ptr) as any ptr
declare function GetChild        cdecl alias "GetChild"       (ent as ENTITY, child_no as integer) as ENTITY

declare function DeltaPitch      cdecl alias "DeltaPitch"     (ent as ENTITY, other as ENTITY) as single
declare function DeltaYaw        cdecl alias "DeltaYaw"       (ent as ENTITY, other as ENTITY) as single

declare sub      EntityColor     cdecl alias "EntityColor"    (ent as ENTITY, red as single, green as single, blue as single)
declare sub      EntityAlpha     cdecl alias "EntityAlpha"    (ent as ENTITY, alpha as single)
declare sub      EntityAutoFade  cdecl alias "EntityAutoFade" (ent as ENTITY, near as single, far as single)
declare sub      EntityBlend     cdecl alias "EntityBlend"    (ent as ENTITY, blend as integer)
declare sub      EntityBox       cdecl alias "EntityBox"      (ent as ENTITY, x as single, y as single, z as single, w as single, h as single, d as single)
declare function EntityClass     cdecl alias "EntityClass"    (ent as ENTITY) as zstring ptr
declare function EntityCollided  cdecl alias "EntityCollided" (ent as ENTITY, type_no as integer) as any ptr
declare function EntityDistance  cdecl alias "EntityDistance" (ent as ENTITY, other as ENTITY) as single
declare sub      EntityFX        cdecl alias "EntityFX"       (ent as ENTITY, fx as integer)
declare function EntityInView    cdecl alias "EntityInView"   (ent as ENTITY, cam as CAMERA) as integer
declare function EntityName      cdecl alias "EntityName"     (ent as ENTITY) as zstring ptr
declare sub      EntityOrder     cdecl alias "EntityOrder"    (ent as ENTITY, order as integer)
declare sub      EntityParent    cdecl alias "EntityParent"   (ent as ENTITY, parent_ent as any ptr, glob as integer=1)
declare sub      EntityRadius    cdecl alias "EntityRadius"   (ent as ENTITY, radius_x as single, radius_y as single=0)
declare sub      EntityShininess cdecl alias "EntityShininess"(ent as ENTITY, shine as single)
declare sub      EntityTexture   cdecl alias "EntityTexture"  (ent as ENTITY, tex as TEXTURE, frame as integer=0, index as integer=0)
declare sub      EntityType      cdecl alias "EntityType"     (ent as ENTITY, type_no as integer, recursive as integer=0)
declare function EntityVisible   cdecl alias "EntityVisible"  (src_ent as ENTITY, dest_ent as ENTITY) as integer

declare function TranslateEntity cdecl alias "TranslateEntity"(ent as ENTITY, x as single, y as single, z as single, glob as integer=0) as integer
declare function EntityX         cdecl alias "EntityX"        (ent as ENTITY, glob as integer=0) as single
declare function EntityY         cdecl alias "EntityY"        (ent as ENTITY, glob as integer=0) as single
declare function EntityZ         cdecl alias "EntityZ"        (ent as ENTITY, glob as integer=0) as single

declare sub      ScaleEntity     cdecl alias "ScaleEntity"    (ent as ENTITY, x as single, y as single, z as single, glob as integer=0)
declare function EntityScaleX    cdecl alias "EntityScaleX"   (ent as ENTITY, glob as integer=0) as single
declare function EntityScaleY    cdecl alias "EntityScaleY"   (ent as ENTITY, glob as integer=0) as single
declare function EntityScaleZ    cdecl alias "EntityScaleZ"   (ent as ENTITY, glob as integer=0) as single

declare sub      RotateEntity    cdecl alias "RotateEntity"   (ent as ENTITY, x as single, y as single, z as single, glob as integer=0)
declare function EntityPitch     cdecl alias "EntityPitch"    (ent as ENTITY, glob as integer=0) as single
declare function EntityYaw       cdecl alias "EntityYaw"      (ent as ENTITY, glob as integer=0) as single
declare function EntityRoll      cdecl alias "EntityRoll"     (ent as ENTITY, glob as integer=0) as single

declare function ExtractAnimSeq  cdecl alias "ExtractAnimSeq" (ent as ENTITY, first_frame as integer, last_frame as integer, seq as integer=0) as integer

declare function GetEntityBrush  cdecl alias "GetEntityBrush" (ent as ENTITY) as BRUSH
declare function GetEntityType   cdecl alias "GetEntityType"  (ent as ENTITY) as integer
declare function GetMatElement   cdecl alias "GetMatElement"  (ent as ENTITY, row as integer, col as integer) as single
declare function GetParentEntity cdecl alias "GetParentEntity"(ent as ENTITY) as ENTITY
declare sub      HideEntity      cdecl alias "HideEntity"     (ent as ENTITY)
declare sub      MoveEntity      cdecl alias "MoveEntity"     (ent as ENTITY, x as single, y as single, z as single)
declare sub      NameEntity      cdecl alias "NameEntity"     (ent as ENTITY, name as zstring ptr)
declare function PaintEntity     cdecl alias "PaintEntity"    (ent as ENTITY, br as BRUSH) as integer
declare sub      PointEntity     cdecl alias "PointEntity"    (ent as ENTITY, target_ent as any ptr, roll as single=0)
declare sub      PositionEntity  cdecl alias "PositionEntity" (ent as ENTITY, x as single, y as single, z as single, glob as integer=0)
declare sub      ResetEntity     cdecl alias "ResetEntity"    (ent as ENTITY)

declare sub      SetAnimTime     cdecl alias "SetAnimTime"    (ent as ENTITY, time as single, seq as integer=0)
declare sub      ShowEntity      cdecl alias "ShowEntity"     (ent as ENTITY)
declare function TurnEntity      cdecl alias "TurnEntity"     (ent as ENTITY, x as single, y as single, z as single, glob as integer=0) as integer

declare function LinePick        cdecl alias "LinePick"       (x as single, y as single, z as single, dx as single, dy as single, dz as single, radius as single=0) as any ptr

declare function EntityPick      cdecl alias "EntityPick"     (ent as ENTITY, range as single) as any ptr
declare sub      EntityPickMode  cdecl alias "EntityPickMode" (ent as ENTITY, pick_mode as PICK_MODE, obscurer as integer=1)

declare function PickedEntity    cdecl alias "PickedEntity"   as ENTITY
declare function PickedSurface   cdecl alias "PickedSurface"  as SURFACE
declare function PickedTriangle  cdecl alias "PickedTriangle" as integer

declare function PickedX         cdecl alias "PickedX" as single
declare function PickedY         cdecl alias "PickedY" as single
declare function PickedZ         cdecl alias "PickedZ" as single

declare function PickedNX        cdecl alias "PickedNX" as single
declare function PickedNY        cdecl alias "PickedNY" as single
declare function PickedNZ        cdecl alias "PickedNZ" as single

declare function PickedTime      cdecl alias "PickedTime" as single

declare function ProjectedX      cdecl alias "ProjectedX" as single
declare function ProjectedY      cdecl alias "ProjectedY" as single
declare function ProjectedZ      cdecl alias "ProjectedZ" as single

declare function TFormedX        cdecl alias "TFormedX" as single
declare function TFormedY        cdecl alias "TFormedY" as single
declare function TFormedZ        cdecl alias "TFormedZ" as single
declare function TFormNormal     cdecl alias "TFormNormal"(x as single, y as single, z as single, src_ent as any ptr, dest_ent as any ptr) as integer
declare function TFormPoint      cdecl alias "TFormPoint" (x as single, y as single, z as single, src_ent as any ptr, dest_ent as any ptr) as integer
declare function TFormVector     cdecl alias "TFormVector"(x as single, y as single, z as single, src_ent as any ptr, dest_ent as any ptr) as integer

declare function VectorPitch     cdecl alias "VectorPitch"(vx as single, vy as single, vz as single) as single
declare function VectorYaw       cdecl alias "VectorYaw"  (vx as single, vy as single, vz as single) as single

#endif ' __OPENB3D_BI__
